# coding: utf-8

"""
    FlashBlade REST API

    A lightweight client for FlashBlade REST API 2.4, developed by Pure Storage, Inc. (http://www.purestorage.com/).

    OpenAPI spec version: 2.4
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re

import six
import typing

from ....properties import Property
if typing.TYPE_CHECKING:
    from pypureclient.flashblade.FB_2_4 import models

class PolicyRuleObjectAccessCondition(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'source_ips': 'list[str]',
        's3_delimiters': 'list[str]',
        's3_prefixes': 'list[str]'
    }

    attribute_map = {
        'source_ips': 'source_ips',
        's3_delimiters': 's3_delimiters',
        's3_prefixes': 's3_prefixes'
    }

    required_args = {
    }

    def __init__(
        self,
        source_ips=None,  # type: List[str]
        s3_delimiters=None,  # type: List[str]
        s3_prefixes=None,  # type: List[str]
    ):
        """
        Keyword args:
            source_ips (list[str]): If specified, the rule will apply only to requests matching at least one provided IP address or subnet. Each entry must be in standard CIDR format (including an IP address without an associated routing prefix). Can be used with any action.
            s3_delimiters (list[str]): If specified, groups result objects by the specified delimiter. Only top-level groupings will be returned. Can be used with the `s3:ListBucket` and `s3:ListBucketVersions` actions.
            s3_prefixes (list[str]): If specified, restricts access and results based on the prefix of the relevant objects. Can be used with the `s3:ListBucket` and `s3:ListBucketVersions` actions.
        """
        if source_ips is not None:
            self.source_ips = source_ips
        if s3_delimiters is not None:
            self.s3_delimiters = s3_delimiters
        if s3_prefixes is not None:
            self.s3_prefixes = s3_prefixes

    def __setattr__(self, key, value):
        if key not in self.attribute_map:
            raise KeyError("Invalid key `{}` for `PolicyRuleObjectAccessCondition`".format(key))
        self.__dict__[key] = value

    def __getattribute__(self, item):
        value = object.__getattribute__(self, item)
        if isinstance(value, Property):
            return None
        else:
            return value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            if hasattr(self, attr):
                value = getattr(self, attr)
                if isinstance(value, list):
                    result[attr] = list(map(
                        lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                        value
                    ))
                elif hasattr(value, "to_dict"):
                    result[attr] = value.to_dict()
                elif isinstance(value, dict):
                    result[attr] = dict(map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict") else item,
                        value.items()
                    ))
                else:
                    result[attr] = value
        if issubclass(PolicyRuleObjectAccessCondition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyRuleObjectAccessCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
